@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -45,14 +45,15 @@
 #include "input/manager.h"
 #include "input/input_event.h"
 #include "ui/root.h"
+#include "utils/variable_map.h"
 
 #include "command_scheduler.h"
-#include "option_handler.h"
 
 #include "control.h"
 
 Control::Control() :
   m_shutdownReceived(false),
+  m_shutdownQuick(false),
 
   m_ui(new ui::Root()),
   m_core(new core::Manager()),
@@ -61,15 +62,15 @@ Control::Control() :
   m_inputStdin(new input::InputEvent(STDIN_FILENO)),
 
   m_commandScheduler(new CommandScheduler()),
-  m_optionHandler(new OptionHandler()),
+  m_variables(new utils::VariableMap()),
 
   m_tick(0) {
 
   m_inputStdin->slot_pressed(sigc::mem_fun(m_input, &input::Manager::pressed));
 
-  m_taskShutdown.set_slot(rak::mem_fn(this, &Control::receive_shutdown));
+  m_taskShutdown.set_slot(rak::mem_fn(this, &Control::handle_shutdown));
 
-  m_commandScheduler->set_slot_command(rak::mem_fn(m_optionHandler, &OptionHandler::process_command));
+  m_commandScheduler->set_slot_command(rak::mem_fn(m_variables, &utils::VariableMap::process_command));
   m_commandScheduler->set_slot_error_message(rak::mem_fn(m_core, &core::Manager::push_log));
 }
 
@@ -78,7 +79,7 @@ Control::~Control() {
   delete m_input;
 
   delete m_commandScheduler;
-  delete m_optionHandler;
+  delete m_variables;
 
   delete m_ui;
   delete m_display;
@@ -92,12 +93,11 @@ Control::initialize() {
   display::Window::slot_unschedule(rak::make_mem_fun(m_display, &display::Manager::unschedule));
   display::Window::slot_adjust(rak::make_mem_fun(m_display, &display::Manager::adjust_layout));
 
-  m_core->get_poll_manager()->signal_interrupted().connect(sigc::mem_fun(*m_inputStdin, &input::InputEvent::event_read));
-  m_core->get_poll_manager()->signal_interrupted().connect(sigc::ptr_fun(display::Canvas::do_update));
   m_core->get_poll_manager()->get_http_stack()->set_user_agent(std::string(PACKAGE "/" VERSION "/") + torrent::version());
 
   m_core->initialize_second();
   m_core->listen_open();
+  m_core->download_store().enable(m_variables->get_string("session_lock") == "yes");
 
   m_ui->init(this);
 
@@ -110,6 +110,8 @@ Control::cleanup() {
 
   m_inputStdin->remove(m_core->get_poll_manager()->get_torrent_poll());
 
+  m_core->download_store().disable();
+
   m_ui->cleanup();
   m_core->cleanup();
   
@@ -119,20 +121,19 @@ Control::cleanup() {
   display::Canvas::cleanup();
 }
 
-// I think it should be safe to initiate the shutdown from anywhere,
-// but if it isn't, use a delay task.
 void
-Control::receive_shutdown() {
-  if (!m_shutdownReceived) {
+Control::handle_shutdown() {
+  if (!m_shutdownQuick) {
     torrent::listen_close();
-    
     m_core->shutdown(false);
-    m_shutdownReceived = true;
 
     if (!m_taskShutdown.is_queued())
-      priority_queue_insert(&taskScheduler, &m_taskShutdown, cachedTime + 5 * 1000000);
+      priority_queue_insert(&taskScheduler, &m_taskShutdown, cachedTime + rak::timer::from_seconds(5));
 
   } else {
     m_core->shutdown(true);
   }
+
+  m_shutdownQuick = true;
+  m_shutdownReceived = false;
 }
