@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -38,10 +38,10 @@
 #define RTORRENT_CONTROL_H
 
 #include <inttypes.h>
+#include <rak/timer.h>
+#include <rak/priority_queue_default.h>
 #include <torrent/torrent.h>
 
-#include "globals.h"
-
 namespace ui {
   class Root;
 }
@@ -59,7 +59,10 @@ namespace input {
   class Manager;
 }  
 
-class OptionHandler;
+namespace utils {
+  class VariableMap;
+}
+
 class CommandScheduler;
 
 class Control {
@@ -67,13 +70,16 @@ public:
   Control();
   ~Control();
   
-  bool                is_shutdown_completed()       { return m_shutdownReceived && torrent::is_inactive(); }
+  bool                is_shutdown_completed()       { return m_shutdownQuick && torrent::is_inactive(); }
   bool                is_shutdown_received()        { return m_shutdownReceived; }
 
   void                initialize();
   void                cleanup();
 
-  void                receive_shutdown();
+  void                handle_shutdown();
+
+  void                receive_normal_shutdown()     { m_shutdownReceived = true; }
+  void                receive_quick_shutdown()      { m_shutdownReceived = true; m_shutdownQuick = true; }
 
   ui::Root*           ui()                          { return m_ui; }
   core::Manager*      core()                        { return m_core; }
@@ -82,7 +88,7 @@ public:
   input::InputEvent*  input_stdin()                 { return m_inputStdin; }
 
   CommandScheduler*   command_scheduler()           { return m_commandScheduler; }
-  OptionHandler*      option_handler()              { return m_optionHandler; }
+  utils::VariableMap* variables()                   { return m_variables; }
 
   uint64_t            tick() const                  { return m_tick; }
   void                inc_tick()                    { m_tick++; }
@@ -92,6 +98,7 @@ private:
   void operator = (const Control&);
 
   bool                m_shutdownReceived;
+  bool                m_shutdownQuick;
 
   ui::Root*           m_ui;
   core::Manager*      m_core;
@@ -100,7 +107,7 @@ private:
   input::InputEvent*  m_inputStdin;
 
   CommandScheduler*   m_commandScheduler;
-  OptionHandler*      m_optionHandler;
+  utils::VariableMap* m_variables;
 
   uint64_t            m_tick;
 
