@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -137,6 +137,11 @@ CurlGet::set_http_proxy(const char* s) {
   curl_easy_setopt(m_handle, CURLOPT_PROXY, s);
 }
 
+void
+CurlGet::set_bind_address(const char* s) {
+  curl_easy_setopt(m_handle, CURLOPT_INTERFACE, s);
+}
+
 void
 CurlGet::perform(CURLMsg* msg) {
   if (msg->msg != CURLMSG_DONE)
@@ -147,9 +152,7 @@ CurlGet::perform(CURLMsg* msg) {
   else
     m_signalFailed.emit(curl_easy_strerror(msg->data.result));
 
-  if (m_handle != NULL)
-    throw std::logic_error("CurlGet::perform finished but the object wasn't closed.");
-
+  // Do nothing below after emitting the signals.
 }
 
 }
