@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -39,14 +39,18 @@
 #include <fstream>
 #include <sstream>
 #include <stdexcept>
+#include <rak/path.h>
 #include <torrent/bencode.h>
 #include <torrent/exceptions.h>
 
+#include "utils/variable_generic.h"
+
 #include "curl_get.h"
 #include "http_queue.h"
 #include "globals.h"
 #include "manager.h"
 
+#include "download.h"
 #include "download_factory.h"
 
 namespace core {
@@ -60,12 +64,16 @@ DownloadFactory::DownloadFactory(const std::string& uri, Manager* m) :
   m_uri(uri),
   m_session(false),
   m_start(false),
-  m_printLog(true),
-  m_tiedToFile(false) {
+  m_printLog(true) {
 
   m_taskLoad.set_slot(rak::mem_fn(this, &DownloadFactory::receive_load));
   m_taskCommit.set_slot(rak::mem_fn(this, &DownloadFactory::receive_commit));
-}  
+
+  m_variables.insert("connection_leech", new utils::VariableAny(control->variables()->get("connection_leech")));
+  m_variables.insert("connection_seed",  new utils::VariableAny(control->variables()->get("connection_seed")));
+  m_variables.insert("directory",        new utils::VariableAny(control->variables()->get("directory")));
+  m_variables.insert("tied_to_file",     new utils::VariableBool(false));
+}
 
 DownloadFactory::~DownloadFactory() {
   priority_queue_erase(&taskScheduler, &m_taskLoad);
@@ -93,15 +101,15 @@ DownloadFactory::receive_load() {
   if (std::strncmp(m_uri.c_str(), "http://", 7) == 0) {
     // Http handling here.
     m_stream = new std::stringstream;
-    HttpQueue::iterator itr = m_manager->get_http_queue().insert(m_uri, m_stream);
+    HttpQueue::iterator itr = m_manager->http_queue().insert(m_uri, m_stream);
 
     (*itr)->signal_done().slots().push_front(sigc::mem_fun(*this, &DownloadFactory::receive_loaded));
     (*itr)->signal_failed().slots().push_front(sigc::mem_fun(*this, &DownloadFactory::receive_failed));
 
-    m_tiedToFile = false;
+    m_variables.set("tied_to_file", (int64_t)false);
 
   } else {
-    m_stream = new std::fstream(m_uri.c_str(), std::ios::in);
+    m_stream = new std::fstream(rak::path_expand(m_uri).c_str(), std::ios::in | std::ios::binary);
 
     if (m_stream->good())
       receive_loaded();
@@ -133,37 +141,74 @@ DownloadFactory::receive_success() {
 
   Manager::DListItr itr = m_manager->insert(m_stream, m_printLog);
 
-  if (itr == m_manager->get_download_list().end()) {
+  if (itr == m_manager->download_list().end()) {
     // core::Manager should already have added the error message to
     // the log.
     m_slotFinished();
     return;
   }
 
-  torrent::Bencode& bencode = (*itr)->get_bencode();
+  torrent::Bencode& root = (*itr)->get_bencode();
+
+  if (!m_session) {
+    // We only allow session torrents to keep their
+    // 'rtorrent/libtorrent' sections.
+    root.erase_key("rtorrent");
+    root.erase_key("libtorrent");
+  }
+
+  if (!root.has_key("rtorrent") ||
+      !root.get_key("rtorrent").is_map())
+    root.insert_key("rtorrent", torrent::Bencode(torrent::Bencode::TYPE_MAP));
+    
+  torrent::Bencode& rtorrent = root.get_key("rtorrent");
+
+  if (!rtorrent.has_key("state") ||
+      !rtorrent.get_key("state").is_string() ||
+      (rtorrent.get_key("state").as_string() != "stopped" &&
+       rtorrent.get_key("state").as_string() != "started"))
+    rtorrent.insert_key("state", "stopped");
+  
+  if (!rtorrent.has_key("tied_to_file") ||
+      !rtorrent.get_key("tied_to_file").is_string())
+    rtorrent.insert_key("tied_to_file", std::string());
+
+  if (rtorrent.has_key("priority") &&
+      rtorrent.get_key("priority").is_value())
+    (*itr)->variables()->set("priority", rtorrent.get_key("priority").as_value() % 4);
+  else
+    (*itr)->variables()->set("priority", (int64_t)2);
+
+  // Move to 'rtorrent'.
+  (*itr)->variables()->set("connection_leech", m_variables.get("connection_leech"));
+  (*itr)->variables()->set("connection_seed",  m_variables.get("connection_seed"));
+  (*itr)->variables()->set("min_peers",        control->variables()->get("min_peers"));
+  (*itr)->variables()->set("max_peers",        control->variables()->get("max_peers"));
+  (*itr)->variables()->set("max_uploads",      control->variables()->get("max_uploads"));
+
+  if (control->variables()->get("use_udp_trackers").as_string() == "no")
+    (*itr)->enable_udp_trackers(false);
 
   if (m_session) {
-    // Hmm... this safe?
-    if (bencode.get_key("rtorrent").get_key("state").as_string() == "started")
+    if (!rtorrent.has_key("directory") ||
+	!rtorrent.get_key("directory").is_string())
+      (*itr)->variables()->set("directory", m_variables.get("directory"));
+    else
+      (*itr)->variables()->set("directory", rtorrent.get_key("directory"));
+
+    if ((*itr)->variables()->get_string("state") == "started")
       m_manager->start(*itr, m_printLog);
 
-    if (bencode.get_key("rtorrent").has_key("tied") &&
-	bencode.get_key("rtorrent").get_key("tied").is_string())
-      (*itr)->set_tied_to_file(bencode.get_key("rtorrent").get_key("tied").as_string());
-
   } else {
-    // Remove the settings if this isn't a session torrent.
-    //bencode.erase_key("rtorrent");
+    (*itr)->variables()->set("directory", m_variables.get("directory"));
 
-    if (m_tiedToFile) {
-      (*itr)->set_tied_to_file(m_uri);
-      bencode.get_key("rtorrent").insert_key("tied", m_uri);
-    }
+    if (m_variables.get("tied_to_file").as_value())
+      (*itr)->variables()->set("tied_to_file", m_uri);
 
     if (m_start)
       m_manager->start(*itr, m_printLog);
 
-    m_manager->get_download_store().save(*itr);
+    m_manager->download_store().save(*itr);
   }
 
   m_slotFinished();
