@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -41,6 +41,7 @@
 #include <fstream>
 #include <stdio.h>
 #include <unistd.h>
+#include <rak/path.h>
 #include <rak/string_manip.h>
 #include <torrent/bencode.h>
 #include <torrent/exceptions.h>
@@ -52,16 +53,44 @@
 namespace core {
 
 void
-DownloadStore::use(const std::string& path) {
-  m_path = path;
+DownloadStore::enable(bool lock) {
+  if (is_enabled())
+    throw torrent::input_error("Session directory already enabled.");
 
-  if (!m_path.empty() && *m_path.rbegin() != '/')
-    m_path += '/';
+  if (m_path.empty())
+    return;
+
+  if (lock)
+    m_lockfile.set_path(m_path + "rtorrent.lock");
+  else
+    m_lockfile.set_path(std::string());
+
+  if (!m_lockfile.try_lock())
+    throw torrent::input_error("Could not lock session directory: \"" + m_path + "\", held by \"" + m_lockfile.locked_by_as_string() + "\".");
+}
+
+void
+DownloadStore::disable() {
+  if (!is_enabled())
+    return;
+
+  m_lockfile.unlock();
+}
+
+void
+DownloadStore::set_path(const std::string& path) {
+  if (is_enabled())
+    throw torrent::input_error("Tried to change session directory while it is enabled.");
+
+  if (!path.empty() && *path.rbegin() != '/')
+    m_path = rak::path_expand(path + '/');
+  else
+    m_path = rak::path_expand(path);
 }
 
 void
 DownloadStore::save(Download* d) {
-  if (!is_active())
+  if (!is_enabled())
     return;
 
   std::fstream f((create_filename(d) + ".new").c_str(), std::ios::out | std::ios::trunc);
@@ -71,7 +100,18 @@ DownloadStore::save(Download* d) {
 
   f << d->get_bencode();
 
-  if (f.fail())
+  if (!f.good())
+    return;
+
+  f.close();
+
+  // Test the new file, to ensure it is a valid bencode string.
+  f.open((create_filename(d) + ".new").c_str(), std::ios::in);
+
+  torrent::Bencode tmp;
+  f >> tmp;
+
+  if (!f.good())
     return;
 
   f.close();
@@ -81,7 +121,7 @@ DownloadStore::save(Download* d) {
 
 void
 DownloadStore::remove(Download* d) {
-  if (!is_active())
+  if (!is_enabled())
     return;
 
   ::unlink(create_filename(d).c_str());
@@ -89,7 +129,7 @@ DownloadStore::remove(Download* d) {
 
 utils::Directory
 DownloadStore::get_formated_entries() {
-  if (!is_active())
+  if (!is_enabled())
     return utils::Directory();
 
   utils::Directory d(m_path);
