@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -50,6 +50,9 @@
 #include <torrent/bencode.h>
 #include <torrent/exceptions.h>
 
+#include "utils/variable_map.h"
+
+#include "globals.h"
 #include "curl_get.h"
 #include "download.h"
 #include "download_factory.h"
@@ -64,11 +67,6 @@ connect_signal_network_log(Download* d, torrent::Download::SlotString s) {
   d->get_download().signal_network_log(s);
 }
 
-// static void
-// connect_signal_tracker_log(Download* d, torrent::Download::SlotString s) {
-//   d->get_download().signal_tracker_failed(s);
-// }
-
 static void
 connect_signal_storage_log(Download* d, torrent::Download::SlotString s) {
   d->get_download().signal_storage_error(s);
@@ -77,18 +75,18 @@ connect_signal_storage_log(Download* d, torrent::Download::SlotString s) {
 // Hmm... find some better place for all this.
 static void
 delete_tied(Download* d) {
+  const std::string tie = d->variables()->get("tied_to_file").as_string();
+
   // This should be configurable, need to wait for the variable
   // thingie to be implemented.
-  if (!d->tied_to_file().empty())
-    ::unlink(d->tied_to_file().c_str());
+  if (!tie.empty())
+    ::unlink(tie.c_str());
 }
 
 Manager::Manager() :
   m_pollManager(NULL),
-  m_portRandom(false),
   m_portFirst(6890),
-  m_portLast(6999),
-  m_checkHash(true) {
+  m_portLast(6999) {
 }
 
 void
@@ -104,6 +102,7 @@ Manager::initialize_first() {
   torrent::initialize(m_pollManager->get_torrent_poll());
 }
 
+// Most of this should be possible to move out.
 void
 Manager::initialize_second() {
   torrent::Http::set_factory(m_pollManager->get_http_stack()->get_http_factory());
@@ -113,11 +112,8 @@ Manager::initialize_second() {
 
   // Register slots to be called when a download is inserted/erased,
   // opened or closed.
-  m_downloadList.slot_map_insert()["0_initialize_bencode"]  = sigc::mem_fun(*this, &Manager::initialize_bencode);
   m_downloadList.slot_map_insert()["1_connect_network_log"] = sigc::bind(sigc::ptr_fun(&connect_signal_network_log), sigc::mem_fun(m_logComplete, &Log::push_front));
-//   m_downloadList.slot_map_insert()["1_connect_tracker_log"] = sigc::bind(sigc::ptr_fun(&connect_signal_tracker_log), sigc::mem_fun(m_logComplete, &Log::push_front));
   m_downloadList.slot_map_insert()["1_connect_storage_log"] = sigc::bind(sigc::ptr_fun(&connect_signal_storage_log), sigc::mem_fun(m_logComplete, &Log::push_front));
-  //m_downloadList.slot_map_insert()["1_enable_udp_trackers"] = sigc::bind(sigc::mem_fun(&core::Download::enable_udp_trackers), true);
 
   m_downloadList.slot_map_erase()["1_hash_queue_remove"]    = sigc::mem_fun(m_hashQueue, &HashQueue::remove);
   m_downloadList.slot_map_erase()["1_store_remove"]         = sigc::mem_fun(m_downloadStore, &DownloadStore::remove);
@@ -190,7 +186,7 @@ Manager::erase(DListItr itr) {
 void
 Manager::start(Download* d, bool printLog) {
   try {
-    d->get_bencode().get_key("rtorrent").insert_key("state", "started");
+    d->variables()->set("state", "started");
 
     if (d->get_download().is_active())
       return;
@@ -215,7 +211,7 @@ Manager::start(Download* d, bool printLog) {
 void
 Manager::stop(Download* d) {
   try {
-    d->get_bencode().get_key("rtorrent").insert_key("state", "stopped");
+    d->variables()->set("state", "stopped");
 
     m_downloadList.stop(d);
 
@@ -245,7 +241,7 @@ Manager::check_hash(Download* d) {
 
 void
 Manager::receive_download_done(Download* d) {
-  if (m_checkHash) {
+  if (control->variables()->get("check_hash").as_string() == "yes") {
     // Start the hash checking, send completed to tracker after
     // finishing.
     prepare_hash_check(d);
@@ -263,7 +259,7 @@ Manager::listen_open() {
   if (m_portFirst > m_portLast)
     throw torrent::input_error("Invalid port range for listening");
 
-  if (m_portRandom) {
+  if (control->variables()->get("port_random").as_string() == "yes") {
     int boundary = m_portFirst + random() % (m_portLast - m_portFirst + 1);
 
     if (!torrent::listen_open(boundary, m_portLast) &&
@@ -273,20 +269,22 @@ Manager::listen_open() {
   } else {
     if (!torrent::listen_open(m_portFirst, m_portLast))
       throw torrent::input_error("Could not open/bind a port for listening.");
+
   }
 }
 
 void
-Manager::initialize_bencode(Download* d) {
-  torrent::Bencode& bencode = d->get_bencode();
+Manager::bind(const std::string& addr) {
+  if (torrent::listen_port() != 0) {
+    torrent::listen_close();
+    torrent::set_bind_address(addr);
+    listen_open();
 
-  if (!bencode.has_key("rtorrent") ||
-      !bencode.get_key("rtorrent").is_map())
-    bencode.insert_key("rtorrent", torrent::Bencode(torrent::Bencode::TYPE_MAP));
-    
-  if (!bencode.get_key("rtorrent").has_key("state") ||
-      !bencode.get_key("rtorrent").get_key("state").is_string())
-    bencode.get_key("rtorrent").insert_key("state", "stopped");
+  } else {
+    torrent::set_bind_address(addr);
+  }
+
+  m_pollManager->get_http_stack()->set_bind_address(torrent::bind_address());
 }
 
 void
@@ -314,8 +312,11 @@ Manager::receive_download_done_hash_checked(Download* d) {
   if (!d->get_download().is_active())
     m_downloadList.start(d);
 
+  if (control->variables()->get_string("session_on_completion") == "yes")
+    m_downloadStore.save(d);
+
   // Don't send if we did a hash check and found incompelete chunks.
-  //if (d->is_done())
+  if (d->is_done())
     d->get_download().tracker_send_completed();
 }
 
@@ -324,9 +325,10 @@ Manager::try_create_download(const std::string& uri, bool start, bool printLog,
   // Adding download.
   DownloadFactory* f = new DownloadFactory(uri, this);
 
+  f->variables()->set("tied_to_file", tied ? "yes" : "no");
+
   f->set_start(start);
   f->set_print_log(printLog);
-  f->set_tied_to_file(tied);
   f->slot_finished(sigc::bind(sigc::ptr_fun(&rak::call_delete_func<core::DownloadFactory>), f));
   f->load();
   f->commit();
@@ -388,7 +390,7 @@ Manager::try_create_download_expand(const std::string& uri, bool start, bool pri
   if (tied)
     for (std::vector<std::string>::iterator itr = paths.begin(); itr != paths.end(); )
       if (std::find_if(m_downloadList.begin(), m_downloadList.end(),
-		       rak::equal(*itr, std::mem_fun(&Download::tied_to_file))) != m_downloadList.end())
+		       rak::equal(*itr, rak::bind2nd(std::mem_fun(&Download::variable_string), "tied_to_file"))) != m_downloadList.end())
 	itr = paths.erase(itr);
       else
 	itr++;
