@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -60,20 +60,17 @@ public:
 
   Manager();
 
-  DownloadList&       get_download_list()                 { return m_downloadList; }
-  DownloadStore&      get_download_store()                { return m_downloadStore; }
-  HashQueue&          get_hash_queue()                    { return m_hashQueue; }
-  HttpQueue&          get_http_queue()                    { return m_httpQueue; }
+  DownloadList&       download_list()                 { return m_downloadList; }
+  DownloadStore&      download_store()                { return m_downloadStore; }
+  HashQueue&          hash_queue()                    { return m_hashQueue; }
+  HttpQueue&          http_queue()                    { return m_httpQueue; }
 
   PollManager*        get_poll_manager()                  { return m_pollManager; }
   Log&                get_log_important()                 { return m_logImportant; }
   Log&                get_log_complete()                  { return m_logComplete; }
 
-  void                set_port_random(bool v)             { m_portRandom = v; }
   void                set_port_range(int a, int b)        { m_portFirst = a; m_portLast = b; }
 
-  void                set_check_hash(bool state)          { m_checkHash = state; }
-
   // Really should find a more descriptive name.
   void                initialize_first();
   void                initialize_second();
@@ -81,6 +78,8 @@ public:
 
   void                listen_open();
 
+  void                bind(const std::string& addr);
+
   void                shutdown(bool force);
 
   DListItr            insert(std::istream* s, bool printLog = true);
@@ -119,11 +118,8 @@ private:
   Log                 m_logImportant;
   Log                 m_logComplete;
 
-  bool                m_portRandom;
   int                 m_portFirst;
   int                 m_portLast;
-
-  bool                m_checkHash;
 };
 
 }
