@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -51,10 +51,14 @@ public:
   void                refresh()                                               { wnoutrefresh(m_window); }
   static void         refresh_std()                                           { wnoutrefresh(stdscr); }
   void                redraw()                                                { redrawwin(m_window); }
+  static void         redraw_std()                                            { redrawwin(stdscr); }
 
   void                resize(int w, int h)                                    { wresize(m_window, h, w); }
   void                resize(int x, int y, int w, int h);
 
+  static void         resize_term(int x, int y)                               { resizeterm(y, x); }
+  static void         resize_term(std::pair<int, int> dim)                    { resizeterm(dim.second, dim.first); }
+
   int                 get_x()                                                 { int x, y; getyx(m_window, y, x); return x; }
   int                 get_y()                                                 { int x, y; getyx(m_window, y, x); return y; }
   int                 get_width()                                             { int x, y; getmaxyx(m_window, y, x); return x; }
@@ -116,6 +120,8 @@ public:
   static int          get_screen_width()                                      { int x, y; getmaxyx(stdscr, y, x); return x; }
   static int          get_screen_height()                                     { int x, y; getmaxyx(stdscr, y, x); return y; }
 
+  static std::pair<int, int> term_size();
+
   static void         do_update()                                             { doupdate(); }
 
 private:
