@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -60,7 +60,7 @@ WindowDownloadList::~WindowDownloadList() {
 
 void
 WindowDownloadList::redraw() {
-  m_slotSchedule(this, (cachedTime + 1000000).round_seconds());
+  m_slotSchedule(this, (cachedTime + rak::timer::from_seconds(1)).round_seconds());
 
   m_canvas->erase();
 
@@ -83,17 +83,17 @@ WindowDownloadList::redraw() {
   int pos = 0;
 
   while (range.first != range.second) {
-    char buffer[m_canvas->get_width() - 2];
+    char buffer[m_canvas->get_width()];
     char* position;
     char* last = buffer + m_canvas->get_width() - 2;
 
-    position = print_download_title(buffer, last - buffer, *range.first);
+    position = print_download_title(buffer, last, *range.first);
     m_canvas->print(0, pos++, "%c %s", range.first == m_list->get_focus() ? '*' : ' ', buffer);
     
-    position = print_download_info(buffer, last - buffer, *range.first);
+    position = print_download_info(buffer, last, *range.first);
     m_canvas->print(0, pos++, "%c %s", range.first == m_list->get_focus() ? '*' : ' ', buffer);
 
-    position = print_download_status(buffer, last - buffer, *range.first);
+    position = print_download_status(buffer, last, *range.first);
     m_canvas->print(0, pos++, "%c %s", range.first == m_list->get_focus() ? '*' : ' ', buffer);
 
     ++range.first;
