@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -52,9 +52,26 @@ WindowFileList::WindowFileList(core::Download* d, unsigned int* focus) :
   m_focus(focus) {
 }
 
+/*
+std::wstring
+hack_wstring(const std::string& src) {
+  size_t length = ::mbstowcs(NULL, src.c_str(), src.size());
+
+  if (length == (size_t)-1)
+    return std::wstring(L"<invalid>");
+
+  std::wstring dest;
+  dest.resize(length);
+  
+  ::mbstowcs(&*dest.begin(), src.c_str(), src.size());
+
+  return dest;
+}
+*/
+
 void
 WindowFileList::redraw() {
-  m_slotSchedule(this, (cachedTime + 10 * 1000000).round_seconds());
+  m_slotSchedule(this, (cachedTime + rak::timer::from_seconds(10)).round_seconds());
   m_canvas->erase();
 
   if (m_download->get_download().size_file_entries() == 0 ||
@@ -120,7 +137,7 @@ WindowFileList::redraw() {
 
     m_canvas->print(84, pos, "%i - %i",
 		    e.chunk_begin(),
-		    e.chunk_end());
+		    e.chunk_begin() != e.chunk_end() ? (e.chunk_end() - 1) : e.chunk_end());
 
     ++range.first;
     ++pos;
