@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -60,7 +60,7 @@ WindowLog::~WindowLog() {
 
 WindowLog::iterator
 WindowLog::find_older() {
-  return m_log->find_older(cachedTime - 60*1000000);
+  return m_log->find_older(cachedTime - rak::timer::from_seconds(60));
 }
 
 void
@@ -71,7 +71,7 @@ WindowLog::redraw() {
 
   for (core::Log::iterator itr = m_log->begin(), end = find_older(); itr != end && pos < m_canvas->get_height(); ++itr) {
     char buffer[16];
-    print_hhmmss(buffer, 16, static_cast<time_t>(itr->first.seconds()));
+    print_hhmmss(buffer, buffer + 16, static_cast<time_t>(itr->first.seconds()));
 
     m_canvas->print(0, pos++, "(%s) %s", buffer, itr->second.c_str());
   }
