@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -57,7 +57,7 @@ WindowPeerInfo::WindowPeerInfo(core::Download* d, PList* l, PList::iterator* f)
 
 void
 WindowPeerInfo::redraw() {
-  m_slotSchedule(this, (cachedTime + 1000000).round_seconds());
+  m_slotSchedule(this, (cachedTime + rak::timer::from_seconds(1)).round_seconds());
   m_canvas->erase();
 
   int y = 0;
@@ -71,20 +71,22 @@ WindowPeerInfo::redraw() {
 		  d.chunks_size());
 
   char buffer[32], *position;
-  position = print_ddmmyyyy(buffer, 32, static_cast<time_t>(d.creation_date()));
-  position = print_string(position, buffer + 32 - position, " ");
-  position = print_hhmmss(position, buffer + 32 - position, static_cast<time_t>(d.creation_date()));
+  position = print_ddmmyyyy(buffer, buffer + 32, static_cast<time_t>(d.creation_date()));
+  position = print_string(position, buffer + 32, " ");
+  position = print_hhmmss(position, buffer + 32, static_cast<time_t>(d.creation_date()));
 
   m_canvas->print(0, y++, "Created: %s", buffer);
 
   y++;
 
   m_canvas->print(0, y++, "Connection Type: %s ( %s / %s )",
-		  core::Download::connection_type_to_string(m_download->get_connection_current()),
-		  core::Download::connection_type_to_string(m_download->get_connection_leech()),
-		  core::Download::connection_type_to_string(m_download->get_connection_seed()));
-  m_canvas->print(0, y++, "Tied to file: %s",
-		  m_download->tied_to_file().c_str());
+		  m_download->variables()->get("connection_current").as_string().c_str(),
+		  m_download->variables()->get("connection_seed").as_string().c_str(),
+		  m_download->variables()->get("connection_leech").as_string().c_str());
+  m_canvas->print(0, y++, "Priority:        %u", torrent::download_priority(m_download->get_download()));
+
+  m_canvas->print(0, y++, "Directory:       %s", m_download->variable_string("directory").c_str());
+  m_canvas->print(0, y++, "Tied to file:    %s", m_download->variable_string("tied_to_file").c_str());
 
   y++;
 
