@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -36,15 +36,9 @@
 
 #include "config.h"
 
-#include <fstream>
 #include <iostream>
-#include <iterator>
-#include <stdexcept>
 #include <string>
-#include <stdlib.h>
-#include <sstream>
 #include <sigc++/bind.h>
-#include <sigc++/retype_return.h>
 #include <torrent/http.h>
 #include <torrent/torrent.h>
 #include <torrent/exceptions.h>
@@ -63,12 +57,11 @@
 #include "input/bindings.h"
 
 #include "utils/directory.h"
+#include "utils/variable_map.h"
 
 #include "control.h"
 #include "globals.h"
 #include "signal_handler.h"
-#include "option_file.h"
-#include "option_handler.h"
 #include "option_handler_rules.h"
 #include "option_parser.h"
 #include "command_scheduler.h"
@@ -77,46 +70,34 @@
 void do_panic(int signum);
 void print_help();
 
-bool
-is_resized() {
-  static int x = 0;
-  static int y = 0;
-  
-  bool r = display::Canvas::get_screen_width() != x || display::Canvas::get_screen_height() != y;
-
-  x = display::Canvas::get_screen_width();
-  y = display::Canvas::get_screen_height();
-
-  return r;
-}
-
 int
-parse_options(Control* c, OptionHandler* optionHandler, int argc, char** argv) {
+parse_options(Control* c, int argc, char** argv) {
   try {
     OptionParser optionParser;
 
     // Converted.
     optionParser.insert_flag('h', sigc::ptr_fun(&print_help));
 
-    optionParser.insert_option('b', sigc::bind<0>(sigc::mem_fun(*optionHandler, &OptionHandler::process), "bind"));
-    optionParser.insert_option('d', sigc::bind<0>(sigc::mem_fun(*optionHandler, &OptionHandler::process), "directory"));
-    optionParser.insert_option('i', sigc::bind<0>(sigc::mem_fun(*optionHandler, &OptionHandler::process), "ip"));
-    optionParser.insert_option('p', sigc::bind<0>(sigc::mem_fun(*optionHandler, &OptionHandler::process), "port_range"));
-    optionParser.insert_option('s', sigc::bind<0>(sigc::mem_fun(*optionHandler, &OptionHandler::process), "session"));
+    optionParser.insert_option('b', sigc::bind<0>(sigc::mem_fun(c->variables(), &utils::VariableMap::set_string), "bind"));
+    optionParser.insert_option('d', sigc::bind<0>(sigc::mem_fun(c->variables(), &utils::VariableMap::set_string), "directory"));
+    optionParser.insert_option('i', sigc::bind<0>(sigc::mem_fun(c->variables(), &utils::VariableMap::set_string), "ip"));
+    optionParser.insert_option('p', sigc::bind<0>(sigc::mem_fun(c->variables(), &utils::VariableMap::set_string), "port_range"));
+    optionParser.insert_option('s', sigc::bind<0>(sigc::mem_fun(c->variables(), &utils::VariableMap::set_string), "session"));
 
-    optionParser.insert_option_list('o', sigc::mem_fun(*optionHandler, &OptionHandler::process));
+    optionParser.insert_option('O', sigc::mem_fun(c->variables(), &utils::VariableMap::process_command));
+    optionParser.insert_option_list('o', sigc::mem_fun(c->variables(), &utils::VariableMap::set_string));
 
     return optionParser.process(argc, argv);
 
   } catch (torrent::input_error& e) {
-    throw std::runtime_error("Failed to parse command line option: " + std::string(e.what()));
+    throw torrent::input_error("Failed to parse command line option: " + std::string(e.what()));
   }
 }
 
 void
 load_session_torrents(Control* c) {
   // Load session torrents.
-  std::list<std::string> l = c->core()->get_download_store().get_formated_entries().make_list();
+  std::list<std::string> l = c->core()->download_store().get_formated_entries().make_list();
 
   for (std::list<std::string>::iterator first = l.begin(), last = l.end(); first != last; ++first) {
     core::DownloadFactory* f = new core::DownloadFactory(*first, c->core());
@@ -146,7 +127,7 @@ load_arg_torrents(Control* c, char** first, char** last) {
 rak::timer
 client_next_timeout() {
   if (taskScheduler.empty())
-    return 60 * 1000000;
+    return rak::timer::from_seconds(60);
   else if (taskScheduler.top()->time() <= cachedTime)
     return 0;
   else
@@ -157,73 +138,81 @@ int
 main(int argc, char** argv) {
   try {
 
+    // Temporary.
+    //setlocale(LC_ALL, "");
+
     cachedTime = rak::timer::current();
 
-    Control       control;
+    control = new Control;
     
     srandom(cachedTime.usec());
     srand48(cachedTime.usec());
 
-    initialize_option_handler(&control);
+    initialize_option_handler(control);
 
     SignalHandler::set_ignore(SIGPIPE);
-    SignalHandler::set_handler(SIGINT,  sigc::mem_fun(control, &Control::receive_shutdown));
-    SignalHandler::set_handler(SIGSEGV, sigc::bind(sigc::ptr_fun(&do_panic), SIGSEGV));
-    SignalHandler::set_handler(SIGBUS,  sigc::bind(sigc::ptr_fun(&do_panic), SIGBUS));
-    SignalHandler::set_handler(SIGFPE,  sigc::bind(sigc::ptr_fun(&do_panic), SIGFPE));
+    SignalHandler::set_handler(SIGINT,   sigc::mem_fun(control, &Control::receive_normal_shutdown));
+    SignalHandler::set_handler(SIGTERM,  sigc::mem_fun(control, &Control::receive_quick_shutdown));
+    SignalHandler::set_handler(SIGWINCH, sigc::mem_fun(control->display(), &display::Manager::force_redraw));
+    SignalHandler::set_handler(SIGSEGV,  sigc::bind(sigc::ptr_fun(&do_panic), SIGSEGV));
+    SignalHandler::set_handler(SIGBUS,   sigc::bind(sigc::ptr_fun(&do_panic), SIGBUS));
+    SignalHandler::set_handler(SIGFPE,   sigc::bind(sigc::ptr_fun(&do_panic), SIGFPE));
 
-    control.core()->initialize_first();
+    control->core()->initialize_first();
 
-    OptionFile optionFile;
-    optionFile.slot_option(sigc::mem_fun(control.option_handler(), &OptionHandler::process));
+    // Move env and go through "try_import".
+    if (!control->variables()->process_file("~/.rtorrent.rc"))
+      control->core()->get_log_important().push_front("Could not load \"~/.rtorrent.rc\".");
 
-    if (getenv("HOME") && !optionFile.process_file(getenv("HOME") + std::string("/.rtorrent.rc")))
-      control.core()->get_log_important().push_front("Could not load \"~/.rtorrent.rc\".");
+    int firstArg = parse_options(control, argc, argv);
 
-    int firstArg = parse_options(&control, control.option_handler(), argc, argv);
-
-    control.initialize();
-
-    // Just to make sure we did all the stuff on the queue before
-    // loading any torrents.
-    //
-    // Remove this?
-    //rak::priority_queue_perform(&taskScheduler, cachedTime);
+    control->initialize();
 
     // Load session torrents and perform scheduled tasks to ensure
     // session torrents are loaded before arg torrents.
-    load_session_torrents(&control);
+    load_session_torrents(control);
     rak::priority_queue_perform(&taskScheduler, cachedTime);
 
-    load_arg_torrents(&control, argv + firstArg, argv + argc);
+    load_arg_torrents(control, argv + firstArg, argv + argc);
 
-    control.display()->adjust_layout();
+    // Make sure we update the display before any scheduled tasks can
+    // run, so that loading of torrents doesn't look like it hangs on
+    // startup.
+    control->display()->adjust_layout();
+    control->display()->receive_update();
 
-    while (!control.is_shutdown_completed()) {
-      control.inc_tick();
+    while (!control->is_shutdown_completed()) {
+      if (control->is_shutdown_received())
+	control->handle_shutdown();
+
+      control->inc_tick();
 
       cachedTime = rak::timer::current();
       rak::priority_queue_perform(&taskScheduler, cachedTime);
 
       // Do shutdown check before poll, not after.
-      control.core()->get_poll_manager()->poll(client_next_timeout());
+      control->core()->get_poll_manager()->poll(client_next_timeout());
     }
 
-    control.cleanup();
+    control->cleanup();
 
   } catch (torrent::base_error& e) {
     display::Canvas::cleanup();
+    delete control;
 
     std::cout << "Caught exception: " << e.what() << std::endl;
     return -1;
 
   } catch (std::exception& e) {
     display::Canvas::cleanup();
+    delete control;
 
     std::cout << e.what() << std::endl;
     return -1;
   }
 
+  delete control;
+
   return 0;
 }
 
@@ -256,22 +245,6 @@ do_panic(int signum) {
   exit(-1);
 }
 
-void
-receive_tracker_dump(std::istream* s) {
-  std::stringstream filename;
-  filename << "./tracker_dump." << rak::timer::current().seconds();
-
-  std::fstream out(filename.str().c_str(), std::ios::out | std::ios::trunc);
-
-  if (!out.is_open())
-    return;
-  
-  s->seekg(0);
-
-  std::copy(std::istream_iterator<char>(*s), std::istream_iterator<char>(),
-	    std::ostream_iterator<char>(out));
-}
-
 void
 print_help() {
   std::cout << "Rakshasa's BitTorrent client version " VERSION "." << std::endl;
