@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -229,6 +229,16 @@ Download::receive_snub_peer() {
   mark_dirty();
 }
 
+void
+Download::receive_next_priority() {
+  m_download->set_priority((m_download->priority() + 1) % 4);
+}
+
+void
+Download::receive_prev_priority() {
+  m_download->set_priority((m_download->priority() - 1) % 4);
+}
+
 void
 Download::bind_keys() {
   (*m_bindings)['1'] = sigc::bind(sigc::mem_fun(*this, &Download::receive_max_uploads), -1);
@@ -237,6 +247,8 @@ Download::bind_keys() {
   (*m_bindings)['4'] = sigc::bind(sigc::mem_fun(*this, &Download::receive_min_peers), 5);
   (*m_bindings)['5'] = sigc::bind(sigc::mem_fun(*this, &Download::receive_max_peers), -5);
   (*m_bindings)['6'] = sigc::bind(sigc::mem_fun(*this, &Download::receive_max_peers), 5);
+  (*m_bindings)['+'] = sigc::mem_fun(*this, &Download::receive_next_priority);
+  (*m_bindings)['-'] = sigc::mem_fun(*this, &Download::receive_prev_priority);
 
   (*m_bindings)['t'] = sigc::bind(sigc::mem_fun(m_download->get_download(), &torrent::Download::tracker_manual_request), false);
   (*m_bindings)['T'] = sigc::bind(sigc::mem_fun(m_download->get_download(), &torrent::Download::tracker_manual_request), true);
