@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -88,6 +88,9 @@ public:
   void                activate_display(Display d);
   void                disable_display();
 
+  void                receive_next_priority();
+  void                receive_prev_priority();
+
 private:
   Download(const Download&);
   void operator = (const Download&);
