@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -87,6 +87,14 @@ public:
     DISPLAY_MAX_SIZE
   } Display;
 
+  typedef enum {
+    INPUT_NONE,
+    INPUT_LOAD_DEFAULT,
+    INPUT_LOAD_MODIFIED,
+    INPUT_CHANGE_DIRECTORY,
+    INPUT_COMMAND
+  } Input;
+
   DownloadList(Control* c);
   ~DownloadList();
 
@@ -115,13 +123,18 @@ private:
   void                receive_view_download();
   void                receive_exit_download();
 
+  void                receive_next_priority();
+  void                receive_prev_priority();
+
   void                receive_check_hash();
 
-  void                receive_view_input(bool useDefault);
-  void                receive_exit_input(bool useDefault);
+  void                receive_view_input(Input type);
+  void                receive_exit_input(Input type);
 
   void                receive_change(Display d);
 
+  void                receive_download_erased(core::Download* d);
+
   void                task_update();
 
   void                setup_keys();
